quadmompy package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   quadmompy.core
   quadmompy.equations
   quadmompy.moments
   quadmompy.qbmm

Module contents
---------------

.. automodule:: quadmompy
   :members:
   :undoc-members:
   :show-inheritance:
